# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.0.1~d19c8b2',
    built_at='2023-12-12 15:43:36Z',
    sha='d19c8b2407c819c62698a944b3d99f9f83672045',
    branch='HEAD',
    tag='v4.0.1',
)
